// This file is autogenerated. Changes will be overwritten.
#include "NPXROYFXYF/moc_colorschemesmodel.cpp"
#include "NPXROYFXYF/moc_documenthandler.cpp"
#include "NPXROYFXYF/moc_linenumbermodel.cpp"
#include "NPXROYFXYF/moc_texteditor_plugin.cpp"
